@@ -155,7 +155,14 @@ async def generate(
             data = to_openai_params(request)
 
             client = AsyncClient(api_key=api_key, base_url=base_url)
-            response = await client.images.generate(**data)
+            try:
+                response = await client.images.generate(**data)
+            except Exception as e:
+                if "Image width range" in str(e):
+                    data["size"] = "1K"
+                    response = await client.images.generate(**data)
+                else:
+                    raise e
             if images := response.model_dump(exclude_none=True).get("images"):
                 response.data = [{"url": image} for image in images]
                 return response
@@ -217,7 +224,6 @@ if __name__ == '__main__':
 
     # arun(generate(request, api_key=api_key, base_url=base_url))
 
-
     api_key = "FPSXc7a13cdcd4893ff3aa053749d05485a7"
     model = "gemini-2-5-flash-image-preview"
 
