@@ -14,6 +14,7 @@ from meutils.pipe import *
 from meutils.schemas.oneapi import BASE_URL
 from meutils.notice.feishu import send_message
 from meutils.caches import cache, rcache
+from meutils.apis.oneapi.utils import get_user_quota
 
 # https://api.chatfire.cn/api/user/814
 
@@ -41,7 +42,7 @@ headers = {
 # @rcache(ttl=7 * 24 * 3600)
 async def get_api_key_log(api_key: str) -> Optional[list]:  # 日志查询会超时：为了获取 user_id, todo缓存 永久缓存 sk => user
     try:
-        async with httpx.AsyncClient(base_url=BASE_URL) as client:
+        async with httpx.AsyncClient(base_url=BASE_URL, timeout=30) as client:
             response = await client.get("/api/log/token", params={"key": api_key})
             response.raise_for_status()
             data = response.json()
@@ -62,19 +63,21 @@ async def get_user(user_id):
             return data
 
 
+# get_user_quota
 async def get_user_money(api_key):
-    if onelog := await get_api_key_log(api_key):
-        onelog = onelog[0]
-        user_id = onelog['user_id']
-
-        data = await get_user(user_id)
-        logger.debug(data)
-        if data:
-            username = data['data']['username']
-            quota = data['data']['quota']
-            return quota / 500000  # money
-
-    logger.debug(onelog)
+    return await get_user_quota(api_key=api_key) or 0
+    # if onelog := await get_api_key_log(api_key):
+    #     onelog = onelog[0]
+    #     user_id = onelog['user_id']
+    #
+    #     data = await get_user(user_id)
+    #     logger.debug(data)
+    #     if data:
+    #         username = data['data']['username']
+    #         quota = data['data']['quota']
+    #         return quota / 500000  # money
+    #
+    # logger.debug(onelog)
 
 
 # 补偿
@@ -104,7 +107,7 @@ async def update_user_for_refund(user_id, quota: int = 0):  # 1块钱对应50万
 @cache()
 @rcache()
 async def get_user_from_api_key(api_key):
-    async with httpx.AsyncClient(base_url=BASE_URL) as client:
+    async with httpx.AsyncClient(base_url=BASE_URL, timeout=15) as client:
         response = await client.get("/api/log/token", params={"key": api_key})
         response.raise_for_status()
         data = response.json()
@@ -131,15 +134,16 @@ if __name__ == '__main__':
     # payload = arun(get_user(1))
     # print(payload)
     # arun(put_user(payload['data'], -1))
+
     # arun(get_api_key_log("sk-"))
 
     # arun(get_api_key_log(os.getenv("OPENAI_API_KEY")))
 
-    # arun(get_user_money("sk-"))
-    # arun(get_user_from_api_key('sk-idDBqyoDVqCXInnO9uaGLUfwsxY7RhzHSn166z5jOBCBvFmY'))
+    # arun(get_api_key_log('sk-'))
+    arun(get_user_money('sk-x'))
 
-    # arun(get_user_for_quota("sk-"))
+    # arun(get_user_quota("sk-x"))
 
-    arun(get_user(11327))
+    # arun(get_user(11327))
 
     # arun(update_user_for_refund(2, quota=73065879))
