@@ -16,7 +16,7 @@ from meutils.config_utils.lark_utils import get_next_token
 
 from httpx import TimeoutException
 
-from openai import OpenAI, AsyncOpenAI
+from openai import OpenAI, AsyncOpenAI, APIStatusError
 
 
 def skip_cache_func(*args, **kwargs):
@@ -153,6 +153,7 @@ async def check_token_for_moonshot(api_key, threshold: float = 0):
 
 
 @retrying()
+@rcache(ttl=300 * 24 * 3600, skip_cache_func=skip_cache_func)
 async def check_token_for_gemini(api_key):
     if not isinstance(api_key, str):
         return await check_tokens(api_key, check_token_for_gemini)
@@ -217,6 +218,7 @@ async def check_token_for_sophnet(api_key, threshold: float = 1):
 # @rcache(ttl=7 * 24 * 3600, skip_cache_func=skip_cache_func)
 async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[str] = None):
     if not isinstance(api_key, str):
+        logger.error(api_key)
         return await check_tokens(
             api_key,
             partial(check_token_for_volc, purpose=purpose)
@@ -231,17 +233,11 @@ async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[
 
             payload = {
                 # "model": "doubao-seedance-1-0-pro-250528",
-                "model": "doubao-seedance-1-0-lite-i2v-250428",
+                "model": "doubao-seedance-1-0-lite-t2v-250428",
                 "content": [
                     {
                         "type": "text",
                         "text": "无人机以极快速度穿越复杂障碍或自然奇观，带来沉浸式飞行体验  --resolution 480p  --duration 5 --camerafixed false"
-                    },
-                    {
-                        "type": "image_url",
-                        "image_url": {
-                            "url": "https://ark-project.tos-cn-beijing.volces.com/doc_image/seepro_i2v.png"
-                        }
                     }
                 ]
             }
@@ -254,6 +250,8 @@ async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[
             response = requests.request("POST", url, headers=headers, json=payload)
             logger.debug(response.json())
             response.raise_for_status()
+            return True
+
         elif purpose and purpose.startswith(("doubao-seed")):
             response = await client.images.generate(
                 model=purpose,
@@ -262,43 +260,56 @@ async def check_token_for_volc(api_key, threshold: float = 1, purpose: Optional[
                 response_format="url"
             )
             logger.debug(response.json())
+            return True
 
-        else:
-
+        elif purpose == "ModelNotOpen":
+            model = "doubao-seed-1-6-flash-250828"
             response = await client.chat.completions.create(
-                model="deepseek-v3-250324",
+                model=model,
                 messages=[{"role": "user", "content": "hi"}],
                 max_tokens=1
             )
-            # logger.debug(response.json())
+            return False
 
-        return True
+        else:
+            model = "deepseek-v3-1-terminus"
+            response = await client.chat.completions.create(
+                model=model,
+                messages=[{"role": "user", "content": "hi"}],
+                max_tokens=1
+            )
+            return True
     except TimeoutException as e:
         raise
 
     except Exception as e:
         logger.error(f"Error: {e}\n{api_key}")
+
+        if purpose == "ModelNotOpen" and "ModelNotOpen" in str(e):
+            return True
+
         return False
 
 
-@rcache(ttl=7 * 24 * 3600, skip_cache_func=skip_cache_func)
+@rcache(ttl=1 * 24 * 3600, skip_cache_func=skip_cache_func)
 async def check_token_for_volc_with_cache(api_key, threshold: float = 1, purpose: Optional[str] = None):
     return await check_token_for_volc(api_key, threshold=threshold, purpose=purpose)
 
 
 @retrying()
-async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_name: Optional[str] = None):
+async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_name: str = "glm-4.5-flash"):
     if not isinstance(api_key, str):
         return await check_tokens(
             api_key,
             partial(check_token_for_zhipu, threshold=threshold, resource_package_name=resource_package_name)
         )
     try:
-        client = AsyncOpenAI(base_url="https://bigmodel.cn/api/biz/tokenAccounts/list", api_key=api_key)
-        data = await client.get("", cast_to=object)
-        logger.debug(bjson(data))
 
-        if resource_package_name:
+        if not resource_package_name.startswith("glm-"):
+            client = AsyncOpenAI(base_url="https://bigmodel.cn/api/biz/tokenAccounts/list", api_key=api_key)
+
+            data = await client.get("", cast_to=object)
+            logger.debug(bjson(data))
             # print(str(data))
             # if """glm-4.5""" not in str(data): return False
 
@@ -312,9 +323,18 @@ async def check_token_for_zhipu(api_key, threshold: float = 1, resource_package_
                     logger.debug(bjson(d))
                     return d["tokenBalance"] >= threshold
         else:
-            logger.debug(bjson(data))
+            client = AsyncOpenAI(base_url="https://open.bigmodel.cn/api/paas/v4", api_key=api_key)
+
+            response = await client.chat.completions.create(
+                model=resource_package_name,
+                messages=[{"role": "user", "content": "嗨"}],
+                max_tokens=3
+            )
+            logger.debug(response)
             return True
 
+
+
     except TimeoutException as e:
         raise
 
@@ -438,14 +458,16 @@ if __name__ == '__main__':
     # arun(check_token_for_volc(["827b41d2-7e8c-46e2-9854-0720ca1bd2e4"]))
     # r = arun(check_token_for_volc_with_cache(["1"]))
 
-    # arun(check_token_for_volc("279749bd-ba5e-4962-9c65-eb6604b65594"))
-    # arun(check_token_for_volc("8a5af7cb-42a3-4391-ac40-9d0f4502acde", purpose='seedance'))
+    # arun(check_token_for_volc("5f211bf8-3f7d-4c68-9346-ca103f9e6862"))
+    arun(check_token_for_volc_with_cache("c53afe3c-ea60-4d87-a676-ccd49d26da2c"))
+    # arun(check_token_for_volc("76e3bf6d-ac4b-4fce-bbc3-90bef9ff0c30", purpose='seedance'))
+    # arun(check_token_for_volc("16ccf1b7-b42c-4f86-81d8-48c5864eaaf0"))
 
     # arun(check_token_for_ppinfra("sk_mCb5sRGTi6GXkSRp5F679Rbs0V_Hfee3p85lccGXCOo"))
 
     # arun(check_token_for_zhipu(api_key="e130b903ab684d4fad0d35e411162e99.PqyXq4QBjfTdhyCh"))
 
-    arun(check_token_for_fal("f0283d1c-864c-41b1-9fcb-1d853d7db9d9:8266d413f11252c96a02e7d9507474db"))
+    # arun(check_token_for_fal("f0283d1c-864c-41b1-9fcb-1d853d7db9d9:8266d413f11252c96a02e7d9507474db"))
 
     # arun(check_token_for_ppinfra("sk_4Ja29OIUBVwKo5GWx-PRTsRcTyxxRjZDpYxSdPg75QU", threshold=18000))
 
