@@ -13,8 +13,9 @@ from meutils.pipe import *
 from meutils.io.files_utils import to_base64
 from meutils.llm.clients import AsyncOpenAI, zhipuai_client
 from meutils.llm.openai_utils import to_openai_params
+from meutils.llm.token_pool import TokenPool, create_volc_request
 
-from meutils.schemas.openai_types import CompletionRequest
+from meutils.schemas.openai_types import CompletionRequest, CompletionUsage
 
 from meutils.apis.proxy.kdlapi import get_one_proxy
 from openai import APIStatusError
@@ -26,78 +27,20 @@ class Completions(object):
             self,
             base_url: Optional[str] = None,
             api_key: Optional[str] = None,
-            http_client: Optional[httpx.AsyncClient] = None
+            http_client: Optional[httpx.AsyncClient] = None,
+            mode: Optional[str] = None,  # tokens 计算模式
     ):
+        self.mode = mode
+
         self.base_url = base_url
         self.api_key = api_key
 
         self.client = AsyncOpenAI(base_url=self.base_url, api_key=self.api_key, http_client=http_client)
 
     async def create(self, request: CompletionRequest):
-        # todo:
-        # 1. 可思考模型 思考优先
-        # request.thinking = {"type": "enabled"}
-
-        if request.thinking and request.model.startswith("doubao-seed") and request.thinking.get("type") == "disabled":
-            choices = {
-                          "doubao-seed-1-6-250615",
-                          "doubao-seed-1-6-vision-250815"
-                      } - {request.model}
-            request.model = np.random.choice(list(choices))
-
-            logger.debug(request.model)
-
-        elif request.model.startswith("doubao-seed"):
-            request.thinking = {"type": "enabled"}
-            choices = {
-                          "doubao-seed-1-6-250615",
-                          "doubao-seed-1-6-vision-250815",
-                          "doubao-seed-1-6-thinking-250715"
-                      } - {request.model}
-            request.model = np.random.choice(list(choices))
-            if request.model == "doubao-seed-1-6-thinking-250615":
-                request.max_tokens = 16000
-
-        elif request.model.startswith(("doubao-1-5-thinking",)):  # thinking
-            request.thinking = None
-            choices = {
-                          "doubao-1-5-thinking-pro-250415",
-                          "doubao-1-5-ui-tars-250428",
-                      } - {request.model}
-            request.model = np.random.choice(list(choices))
-
-        elif request.model in {"doubao-1-5-thinking-vision-pro-250428"}:  # vision thinking
-            choices = {
-                          "doubao-1-5-ui-tars-250428",
-                      } - {request.model}
-            request.model = np.random.choice(list(choices))
-
-        elif request.model.startswith(("doubao-1-5", "doubao-1.5")):  # nothinking
-            request.thinking = {"type": "disabled"}
-
-            choices = {
-                          "doubao-1-5-pro-32k-250115",
-                          "doubao-1-5-pro-256k-250115",
-                          "doubao-1-5-pro-32k-character-250715",
-                          "doubao-1-5-pro-32k-character-250228",
-                          "doubao-1.5-vision-pro-250328",
-                          "doubao-1-5-vision-pro-32k-250115",
-                          "doubao-1-5-thinking-pro-250415",  # todo 好像没有免费额度
-                          # "doubao-1-5-thinking-pro-m-250428",
-                          # "doubao-1-5-thinking-vision-pro-250428",
-                          "doubao-1-5-ui-tars-250428",
-                      } - {request.model}
-            request.model = np.random.choice(list(choices))
-
-        elif request.model.startswith(("deepseek-",)):  # deepseek => v3-1
-            if request.model.startswith("deepseek-r"):
-                request.thinking = {"type": "enabled"}
-
-            choices = {
-                          "deepseek-v3-1-250821",
-                          "deepseek-v3-1-terminus",
-                      } - {request.model}
-            request.model = np.random.choice(list(choices))
+        if self.mode == "tokens" and any(i in self.base_url for i in {"volc", "doubao"}):
+            request, mini_api_key = await create_volc_request(request)
+            self.api_key = mini_api_key
 
         ###########################################################################
         # 开启视觉模型
@@ -137,40 +80,57 @@ class Completions(object):
                 request.max_tokens = None
                 self.client = zhipuai_client
 
-        elif "deepseek-r" in request.model:
+        elif "deepseek-r" in request.model:  # 参数覆盖即可
             request.separate_reasoning = True  # pp
             # """Error code: 403 - {'code': 403, 'reason': 'NOT_ENOUGH_BALANCE', 'message': 'not enough balance', 'metadata': {}}"""
         ###########################################################################
 
         data = to_openai_params(request)
-        if 'gemini' in request.model:
-            data.pop("seed", None)
-            data.pop("presence_penalty", None)
-            data.pop("frequency_penalty", None)
-            data.pop("extra_body", None)
-
-            if "thinking" in request.model:
-                data['model'] = data['model'].removesuffix("-thinking")  # 开启思考
-                data['reasoning_effort'] = 'low'
+        # if 'gemini' in request.model:
+        #     data.pop("seed", None)
+        #     data.pop("presence_penalty", None)
+        #     data.pop("frequency_penalty", None)
+        #     data.pop("extra_body", None)
+        #
+        #     if "thinking" in request.model:
+        #         data['model'] = data['model'].removesuffix("-thinking")  # 开启思考
+        #         data['reasoning_effort'] = 'low'
 
         # logger.debug(data)
         try:
             response = await self.client.chat.completions.create(**data)
+
+            # tokens
+            if self.mode == "tokens" and not request.stream and response.usage:
+                total_tokens = response.usage.total_tokens
+                await TokenPool('volc').incr_tokens(request.model, self.api_key, total_tokens)
+
             return response
+
         except APIStatusError as e:
             logger.debug(e)
             # logger.debug(e.response.json())
             # logger.debug(e.response.status_code)
+            if e.response.status_code > 403:
+                if self.mode == "tokens" and any(i in self.base_url for i in {"volc", "doubao"}):  # 火山轮询
+                    total_tokens = 10 ** 7
+                    if e.code == "AccountOverdueError":  # 403
+                        pass
+                    elif e.code == "ModelNotOpen":  # 404 大概率账号失效 软删除
+                        total_tokens = 10 ** 8
+
+                    await TokenPool('volc').incr_tokens(request.model, api_key, total_tokens)
+
+                elif any(i in self.base_url for i in {"siliconflow", "modelscope"}):  # 代理
+                    proxy = await get_one_proxy()
+                    client = AsyncOpenAI(
+                        base_url=self.base_url,
+                        api_key=self.api_key,
+                        http_client=httpx.AsyncClient(proxy=proxy, timeout=300)
+                    )
+                    response = await client.chat.completions.create(**data)
+                    return response
 
-            if e.response.status_code > 403 and any(i in self.base_url for i in {"siliconflow", "modelscope"}):
-                proxy = await get_one_proxy()
-                client = AsyncOpenAI(
-                    base_url=self.base_url,
-                    api_key=self.api_key,
-                    http_client=httpx.AsyncClient(proxy=proxy, timeout=100)
-                )
-                response = await client.chat.completions.create(**data)
-                return response
             raise e
 
 
