@@ -256,12 +256,15 @@ MODEL_PRICE = {
 
     # veo
     "veo3": 1,
+    "veo3-fast": 1,
     "veo3-frames": 1,
     "veo3-pro": 4,
     "veo3-pro-frames": 4,
 
-    "veo3.1": 1,
-    "veo3.1-pro": 4,
+    "veo3.1": 0.6,
+    "veo3.1-fast": 0.6,
+    "veo3.1-components": 6,
+    "veo3.1-pro": 3,
 
     # hailuo https://www.minimax.io/price
     "minimax-hailuo-02": 1,
@@ -323,7 +326,7 @@ MODEL_PRICE = {
 
     "tts-pro": 0.03,
 
-    # 官方apit todo 免费模型
+    # 官方api todo 免费模型
     "cogvideox-flash": 0.05,
     "cogvideox-3": 0.3,
 
@@ -333,13 +336,7 @@ MODEL_PRICE = {
     "seedream-video-3.0": 0.5,
 
     # delle3
-    "api-images-kling": 0.04,
-    "api-images-hunyuan": 0.04,
-    "api-images-cogview-3": 0.01,
-    "api-images-stable-diffusion": 0.01,
-
-    "api-images-recraftv3": 0.1,
-    "api-images-seededit": 0.1,
+    "Hunyuan3D-2": 0.05,
 
     "seedream-3.0": 0.05,
     "seededit-3.0": 0.05,
@@ -742,6 +739,8 @@ MODEL_RATIO = {
     "kimi-128k": 5,
     "kimi-dev-72b": 1,
     "kimi-k2-turbo-preview": 2,
+    "kimi-k2-thinking": 2,
+    "kimi-k2-thinking-turbo": 4,
 
     "kimi-k2-250711": 2,
     "kimi-k2-0711-preview": 2,
@@ -1383,6 +1382,8 @@ COMPLETION_RATIO = {
     "kimi-k2-250905": 4,
     "kimi-k2-0905-preview": 4,
     "kimi-k2-instruct-0905": 4,
+    "kimi-k2-thinking": 4,
+    "kimi-k2-thinking-turbo": 7.25,
 
     "moonshot-v1-8k": 5,
     "moonshot-v1-32k": 4,
